Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(548)

Unified Diff: chrome/browser/previews/previews_infobar_delegate.h

Issue 2848293002: Adding the Previews infobar to pages that show a client LoFi image (Closed)
Patch Set: removed range check Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/previews/previews_infobar_delegate.h
diff --git a/chrome/browser/previews/previews_infobar_delegate.h b/chrome/browser/previews/previews_infobar_delegate.h
index f362be5c2a58d71a574dda0d2228860e1cc085b7..0bbf537f23518dd8ab648d0543001dcb9a867517 100644
--- a/chrome/browser/previews/previews_infobar_delegate.h
+++ b/chrome/browser/previews/previews_infobar_delegate.h
@@ -21,10 +21,13 @@ class PreviewsInfoBarDelegate : public ConfirmInfoBarDelegate {
public:
// The type of the infobar. It controls the strings and what UMA data is
// recorded for the infobar.
+ // TODO(ryansturm): Combine PreviewsInfoBarType with previews::PreviewsType.
+ // crbug.com/704335
enum PreviewsInfoBarType {
- LOFI, // Server-side image replacement.
- LITE_PAGE, // Server-side page rewrite.
- OFFLINE, // Offline copy of the page.
+ LOFI, // Server-side image replacement.
+ LITE_PAGE, // Server-side page rewrite.
+ OFFLINE, // Offline copy of the page.
+ CLIENT_LOFI, // Client-side image replacement.
sclittle 2017/05/03 18:40:21 Since both Server LoFi and Client LoFi will often
RyanSturm 2017/05/03 18:48:52 I'd prefer to know the difference between the opt
sclittle 2017/05/03 19:02:47 Client LoFi tries to target all http:// and https:
};
typedef base::Callback<void(bool opt_out)> OnDismissPreviewsInfobarCallback;

Powered by Google App Engine
This is Rietveld 408576698